@@ -2,7 +2,6 @@ import unittest
 
 from py_nextbus import NextBusClient
 
-
 TEST_AGENCY = "sfmta-cis"
 TEST_ROUTE = "F"
 TEST_STOP = "4513"
@@ -14,8 +13,8 @@ class ClientTest(unittest.TestCase):
     def setUp(self):
         self.client = NextBusClient()
 
-    def test_list_gencies(self):
-        agencies: list[dict[str, str]] = self.client.agencies()
+    def test_list_agencies(self):
+        agencies = self.client.agencies()
 
         # Check critical agency keys
         for agency in agencies:
